/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is ForecastFox.
 *
 * The Initial Developer of the Original Code is
 * Jon Stritar <jstritar@MIT.EDU>.
 * Portions created by the Initial Developer are Copyright (C) 2005
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 * Jon Stritar <jstritar@MIT.EDU>
 * Richard Klein <richwklein@mchsi.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

var gProfiles = null;

function profilesLoad()
{
  gProfiles = new ProfilesModule();
  gProfiles.init();
}

function profilesUnload()
{
  gProfiles.destroy();
  gProfiles = null;
}

function ProfilesModule()
{
  this.wrappedJSObject = this;
  return this;
}

ProfilesModule.prototype = {
  mProfiles: null,
  mType: null,
  mBundle: null,
  mText: null,
  mBranch: null,
  mPrompt: null,
  
  init: function()
  {
    this.mProfiles = Components.classes["@mozdev.org/forecastfox/profiles;1"].getService(Components.interfaces.nsIForecastfoxProfiles);
    this.mType = window.arguments[0];
    this.mBundle = document.getElementById("ff-bundle-profiles");  
    this.mText = document.getElementById("ff-text-name");
                 
    //get preference branch
    var prefService = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefService); 
    this.mBranch = prefService.getBranch("forecastfox.");
      
    //set description
    document.getElementById("ff-desc-type").value = this.mBundle.getString("ff.profiles." + this.mType);
    switch (this.mType) {
      case "create":
        this.mText.value = "";
        break;
      case "rename":
        this.mText.value = this.mBranch.getCharPref("profile.current");
        break;
      case "delete":
        this.mText.disabled = true;
        this.mText.value = this.mBranch.getCharPref("profile.current");
        break;   
    }
    
    //set focus
    if (this.mType != "delete") {
      this.mText.focus();
      this.mText.select();
    }  
  },
  
  destroy: function()
  {
    this.mProfiles = null;
    this.mType = null;
    this.mBundle = null;
    this.mText = null;
    this.mBranch = null;
    this.mPrompt = null; 
  },

  accept: function()
  {
    var x;
    var count = {};
    var names = this.mProfiles.getNames(count);
      
    if (!this.validate())
      return;
      
    switch (this.mType) {
      case "create":
        this.mProfiles.saveProfile(this.mText.value);
        this.mBranch.setCharPref("profile.current", this.mText.value);
        break;
      case "rename":
        var current = this.mBranch.getCharPref("profile.current");
        this.mProfiles.renameProfile(current, this.mText.value);
        break;         
      case "delete":
        //switch to different profile
        for (x=0; x < count.value; x++) {
          if (names[x] != this.mText.value)
            break;   
        }
        this.mBranch.setCharPref("profile.current", names[x]);
        this.mProfiles.deleteProfile(this.mText.value);
        break;         
    }
   
    window.close(); 
  },
  
  validate: function()
  {
    var x;
    var count = {};
    var names = this.mProfiles.getNames(count);
    
    switch (this.mType) {
      case "create":
        //check if valide profile name entered
        if (this.mText.value == "") {
          this.alert("ff.profiles.invalid");
          return false;
        }
    
        //check if a profile by this name already exists
        for (x=0; x < count.value; x++ ) {
          if (names[x] == this.mText.value) {
            this.alert("ff.profiles.exists");
            return false;
          }  
        }
        break;
      case "rename":
        //check if valide profile name entered
        if (this.mText.value == "") {
          this.alert("ff.profiles.invalid");
          return false;
        }
    
        //check if a profile by this name already exists
        for (x=0; x < count.value; x++ ) {
          if (names[x] == this.mText.value) {
            this.alert("ff.profiles.exists");
            return false;
          }  
        }      
        break;         
      case "delete":
        //check that we aren't the last profile
        if (count.value == 1) {
          this.alert("ff.profiles.last");
          return false; 
        }
        break;      
    }
    
    return true;
  },
  
  alert: function(aText)
  {
    if (!this.mPrompt)
      this.mPrompt = Components.classes["@mozilla.org/embedcomp/prompt-service;1"].getService(Components.interfaces.nsIPromptService);
    this.mPrompt.alert(window, this.mBundle.getString("ff.alert"), this.mBundle.getString(aText));
  },
  
  openLink: function(aEvent, aTWC)
  {
    var url = aEvent.currentTarget.getAttribute("url");
    if (aTWC)
      url = url + "?prod=" + this.mUpdate.productCode + "&par=" + this.mUpdate.partnerId;

    window.openDialog("chrome://browser/content/browser.xul", "_blank", "chrome,all,dialog=no", url, null, null);
  }  
}